from toboso.base import open_database, get_session_manager, get_connection, \
     get_user_database
SITE = 'toboso'
SITE_NAME = 'Toboso Calendar'
SUPPRESS_EMAIL = 1

# Used as the default SMTP sender for mail sent by the site (ie. by
# dulcinea.sendmail.sendmail()), so that any bounces will go to us.
MAIL_SMTP_SENDER = 'webmaster@example.org'



'''$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/toboso/lib/local_ui.py $
$Id: local_ui.py 23516 2004-02-19 18:32:52Z abenard $
'''

from dulcinea.immutable_list import ImmutableList as _ImmutableList
from dulcinea.ui.user.util import format_user_profile, \
     format_personal_profile_links, format_user_profile_links

from toboso.ui.standard import header, footer

format_login_agreement = lambda : None # No login agreement

FEEDBACK_DOMAIN = 'yourdomain.here'

VALID_FEEDBACK_ADDRESSES = _ImmutableList(['boss'])
